package com.jiuqi.dna.ide.designer.commands;

import com.jiuqi.dna.ide.designer.DesignerMessages;
import com.jiuqi.dna.ide.designer.elements.ICompositeElement;
import com.jiuqi.dna.ide.designer.elements.IDesignerElement;
import com.jiuqi.dna.ide.designer.elements.IFigureElement;
import com.jiuqi.dna.ide.designer.elements.ILinkElement;
import java.util.ArrayList;
import java.util.Iterator;
import org.eclipse.gef.commands.Command;

/* loaded from: com_jiuqi_dna_ide_designer_commands.jar:com/jiuqi/dna/ide/designer/commands/DesignerElementDeleteCommand.class */
public class DesignerElementDeleteCommand extends Command {
    private IDesignerElement element;
    private ArrayList<IFigureElement> children = new ArrayList<>();
    private ArrayList<ILinkElement> links = new ArrayList<>();
    private boolean wasRemoved;

    public DesignerElementDeleteCommand(IDesignerElement element) {
        if (element == null) {
            throw new NullPointerException("参数element不能为NULL！");
        }
        this.element = element;
        setLabel(DesignerMessages.DesignerElementDeleteCommandLabel);
    }

    public boolean canExecute() {
        return this.element.isInitialized() && this.element.isDisposable();
    }

    public void execute() {
        this.children.clear();
        this.links.clear();
        if (this.element instanceof IFigureElement) {
            if (this.element instanceof ICompositeElement) {
                addChildren((ICompositeElement) this.element);
            }
            addLinks((IFigureElement) this.element);
        }
        this.element.dispose();
        this.wasRemoved = true;
    }

    private void addChildren(ICompositeElement composite) {
        Iterator it = composite.getChildren().iterator();
        while (it.hasNext()) {
            IFigureElement iFigureElement = (IDesignerElement) it.next();
            if (iFigureElement instanceof IFigureElement) {
                if (iFigureElement instanceof ICompositeElement) {
                    addChildren((ICompositeElement) iFigureElement);
                }
                this.children.add(iFigureElement);
                addLinks(iFigureElement);
            }
        }
    }

    private void addLinks(IFigureElement elem) {
        this.links.addAll(elem.getSourceLinks());
        this.links.addAll(elem.getTargetLinks());
    }

    public void undo() {
        this.element.init();
        if (this.element instanceof IFigureElement) {
            if (this.element instanceof ICompositeElement) {
                initChildren();
            }
            initLinks();
        }
        this.wasRemoved = false;
    }

    private void initChildren() {
        for (int i = this.children.size() - 1; i >= 0; i--) {
            this.children.get(i).init();
        }
    }

    private void initLinks() {
        Iterator<ILinkElement> it = this.links.iterator();
        while (it.hasNext()) {
            ILinkElement link = it.next();
            link.init();
        }
    }

    public boolean canUndo() {
        return this.wasRemoved;
    }
}
